semi_logger library

Classes

SemiLogContent
SemiLogger
The logger is static in app. That mean is the logger config will be apply on all logger object on your app. Use instance for custom a special logger.
SemiLogLevelData
data for block print
SemiLogStyle
The style for each level
SemiLogStyleData
Your styles of logger

Enums

ANSIStyles
Base on ANSI Escape code, this enum define the support print log style and color
SemiLogLevel
Log level for styling print

Extensions

SemiLogLevelX on SemiLogLevel

Constants

accessDenied → const String
badGateway → const String
badRequest → const String
castDataError → const String
connectionFail → const String
emptyList → const String
fileNotFound → const String
forbidden → const String
indexOutOfBounds → const String
methodNotAllowed → const String
noInternetAccess → const String
nullDataError → const String
outOfMemory → const String
permissionDenied → const String
requestTimeOut → const String
serverError → const String
timeout → const String
unauthorized → const String
unknown → const String
whitespace → const String

Functions

apply(String text, {ANSIStyles? color, ANSIStyles? bg, ANSIStyles? fontStyle}) String
return text with ANSI format example: print('\u{1B}[31m\u{1B}[103mHello World!\u{1B}[0m');

Exceptions / Errors

SemiException
Depend on Exception, SemiException provide a model, which is contains basic data for handling error and exception.